@@ -12,6 +12,7 @@
 #define WIDGETBASE_H
 
 #include "basictypes.h"
+#include "icon_utils.h"
 
 #include <QColor>
 #include <QDomDocument>
@@ -23,6 +24,37 @@
 
 // forward declarations
 class QAction;
+class ActivityWidget;
+class ActorWidget;
+class ArtifactWidget;
+class AssociationWidget;
+class BoxWidget;
+class CategoryWidget;
+class ClassifierWidget;
+class CombinedFragmentWidget;
+class ComponentWidget;
+class DatatypeWidget;
+class EntityWidget;
+class EnumWidget;
+class FloatingDashLineWidget;
+class FloatingTextWidget;
+class ForkJoinWidget;
+//class InterfaceWidget;
+class MessageWidget;
+class NodeWidget;
+class NoteWidget;
+class ObjectNodeWidget;
+class ObjectWidget;
+class PackageWidget;
+class PinWidget;
+class PortWidget;
+class PinPortBase;
+class PreconditionWidget;
+class RegionWidget;
+class SignalWidget;
+class StateWidget;
+//class TextWidget;
+class UseCaseWidget;
 class UMLDoc;
 class UMLObject;
 class UMLScene;
@@ -41,7 +73,7 @@ class WidgetBase : public QGraphicsObject
 public:
     enum WidgetType
     {
-        wt_MIN = 299,               // lower bounds check value
+        wt_Min = 299,               // lower bounds check value
         wt_UMLWidget,               // does not have UMLObject representation
         wt_Actor,                   // has UMLObject representation
         wt_UseCase,                 // has UMLObject representation
@@ -72,11 +104,13 @@ public:
         wt_Region,
         wt_Category,                // has UMLObject representation
         wt_Port,                    // has UMLObject representation
-        wt_MAX                      // upper bounds check value
+        wt_Instance,                // has UMLObject representation == wt_Object
+        wt_Max                      // upper bounds check value
     };
 
     static QString toString(WidgetType wt);
     static QString toI18nString(WidgetType wt);
+    static Icon_Utils::IconType toIcon(WidgetType wt);
 
     explicit WidgetBase(UMLScene * scene, WidgetType type= wt_UMLWidget);
     virtual ~WidgetBase();
@@ -136,10 +170,13 @@ public:
     virtual QFont font() const;
     virtual void setFont(const QFont& font);
 
-    virtual void showPropertiesDialog();
+    bool autoResize();
+    void setAutoResize(bool state);
 
-    virtual bool loadFromXMI(QDomElement &qElement);
-    virtual void saveToXMI(QDomDocument &qDoc, QDomElement &qElement);
+    virtual bool showPropertiesDialog();
+
+    virtual bool loadFromXMI1(QDomElement &qElement);
+    virtual void saveToXMI1(QDomDocument &qDoc, QDomElement &qElement);
 
     WidgetBase& operator=(const WidgetBase& other);
 
@@ -153,6 +190,69 @@ public:
 
     virtual void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget = 0);
 
+    bool isActivityWidget()         { return baseType() == wt_Activity; }
+    bool isActorWidget()            { return baseType() == wt_Actor; }
+    bool isArtifactWidget()         { return baseType() == wt_Artifact; }
+    bool isAssociationWidget()      { return baseType() == wt_Association; }
+    bool isBoxWidget()              { return baseType() == wt_Box; }
+    bool isCategoryWidget()         { return baseType() == wt_Category; }
+    bool isClassWidget()            { return baseType() == wt_Class; }
+    bool isCombinedFragmentWidget() { return baseType() == wt_CombinedFragment; }
+    bool isComponentWidget()        { return baseType() == wt_Component; }
+    bool isDatatypeWidget()         { return baseType() == wt_Datatype; }
+    bool isEntityWidget()           { return baseType() == wt_Entity; }
+    bool isEnumWidget()             { return baseType() == wt_Enum; }
+    bool isFloatingDashLineWidget() { return baseType() == wt_FloatingDashLine; }
+    bool isForkJoinWidget()         { return baseType() == wt_ForkJoin; }
+    bool isInterfaceWidget()        { return baseType() == wt_Interface; }
+    bool isMessageWidget()          { return baseType() == wt_Message; }
+    bool isNodeWidget()             { return baseType() == wt_Node; }
+    bool isNoteWidget()             { return baseType() == wt_Note; }
+    bool isObjectNodeWidget()       { return baseType() == wt_ObjectNode; }
+    bool isObjectWidget()           { return baseType() == wt_Object; }
+    bool isPackageWidget()          { return baseType() == wt_Package; }
+    bool isPinWidget()              { return baseType() == wt_Pin; }
+    bool isPortWidget()             { return baseType() == wt_Port; }
+    bool isPreconditionWidget()     { return baseType() == wt_Precondition; }
+    bool isRegionWidget()           { return baseType() == wt_Region; }
+    bool isSignalWidget()           { return baseType() == wt_Signal; }
+    bool isStateWidget()            { return baseType() == wt_State; }
+    bool isTextWidget()             { return baseType() == wt_Text; }
+    bool isUseCaseWidget()          { return baseType() == wt_UseCase; }
+
+    ActivityWidget* asActivityWidget();
+    ActorWidget* asActorWidget();
+    ArtifactWidget* asArtifactWidget();
+    AssociationWidget* asAssociationWidget();
+    BoxWidget* asBoxWidget();
+    CategoryWidget* asCategoryWidget();
+    ClassifierWidget* asClassifierWidget();
+    CombinedFragmentWidget* asCombinedFragmentWidget();
+    ComponentWidget* asComponentWidget();
+    DatatypeWidget* asDatatypeWidget();
+    EntityWidget* asEntityWidget();
+    EnumWidget* asEnumWidget();
+    FloatingDashLineWidget* asFloatingDashLineWidget();
+    ForkJoinWidget* asForkJoinWidget();
+    //InterfaceWidget* asInterfaceWidget();
+    MessageWidget* asMessageWidget();
+    NodeWidget* asNodeWidget();
+    NoteWidget* asNoteWidget();
+    ObjectNodeWidget* asObjectNodeWidget();
+    ObjectWidget* asObjectWidget();
+    PackageWidget* asPackageWidget();
+    PinWidget* asPinWidget();
+    PinPortBase* asPinPortBase();
+    PortWidget* asPortWidget();
+    PreconditionWidget* asPreconditionWidget();
+    RegionWidget* asRegionWidget();
+    SignalWidget* asSignalWidget();
+    StateWidget* asStateWidget();
+    FloatingTextWidget* asFloatingTextWidget();
+//    TextWidget* asTextWidget();
+    UseCaseWidget* asUseCaseWidget();
+    UMLWidget* asUMLWidget();
+
 public Q_SLOTS:
     virtual void slotMenuSelection(QAction *trigger);
 
@@ -188,11 +288,12 @@ protected:
      * been explicitly set for this widget.
      * These are saved to XMI.
      */
-    bool m_usesDiagramTextColor;
-    bool m_usesDiagramLineColor;
     bool m_usesDiagramFillColor;
-    bool m_usesDiagramUseFillColor;
+    bool m_usesDiagramLineColor;
     bool m_usesDiagramLineWidth;
+    bool m_usesDiagramTextColor;
+    bool m_usesDiagramUseFillColor;
+    bool m_autoResize;
 };
 
 #endif
